@@ -1,18 +1,25 @@
 #include <QtGui/QApplication>
-#include "mainwindow.h"
 #include <QtDBus/QtDBus>
 
+#include "globals.h"
+
+#ifdef Q_WS_MAEMO_5
+#include "maemo_mainwindow.h"
+#else
+#include "mainwindow.h"
+#endif
+
 int main(int argc, char *argv[])
 {
 
     QApplication a(argc, argv);
     a.setApplicationName("munadi");
-    a.setApplicationVersion("0.1");
-    a.setOrganizationName("HaqManInc");
+    a.setApplicationVersion(APP_VERSION);
+    a.setOrganizationName("munadi");
 
     MainWindow w;
 
-#ifdef maemo5
+#ifdef Q_WS_MAEMO_5
 
     if (!QDBusConnection::sessionBus().isConnected()) {
         qWarning("Cannot connect to the D-Bus session bus.");
