@@ -3,8 +3,11 @@
 
 #include <QtGui>
 #include <QtCore>
+#ifdef Q_WS_MAEMO_5
+    #include <QDesktopWidget>
+#endif
 #include "munadiengine.h"
-#include "addcitydialog.h"
+#include "settingsdialog.h"
 
 namespace Ui
 {
@@ -24,12 +27,13 @@ public:
 private:
     Ui::MainWindow *ui;
     MunadiEngine * munadi;
-    addCityDialog * addCity;
+    settingsDialog * addCity;
     QTimer * timer;
     bool closeWindow;
     void loadSettings();
     void saveSettings();
-#ifndef maemo5
+    bool eventFilter(QObject *, QEvent *);
+#ifndef Q_WS_MAEMO_5
     QSystemTrayIcon * tray;
     QMenu * trayMenu;
     void createTrayMenu();
@@ -40,21 +44,17 @@ protected:
     void showEvent(QShowEvent *);
 
 private slots:
-    void on_pbRandHadith_clicked();
-    void on_actionShow_Hadith_triggered();
     void on_actionNew_City_triggered();
     void updateDisplay();
     void toggleView(){ isVisible() ? hide() : show(); }
     void on_actionE_xit_triggered();
-    void on_pbCloseHadith_clicked();
     void on_actionAbout_Munadi_triggered();
-    void on_btnHadithNext_clicked();
-    void on_btnHadithPrev_clicked();
     void on_actionPlay_Stop_Athan_triggered();
     void on_actionTEST_PRAYER_triggered();
     void on_actionShow_On_Athan_triggered();
-#ifndef maemo5
+#ifdef Q_WS_MAEMO_5
     void iconActivated(QSystemTrayIcon::ActivationReason reason);
+    void orientationChanged();
 #endif
 
 public slots:
