@@ -11,13 +11,9 @@
 #include <QStringList>
 
 #ifdef SFML
-
 #include <SFML/Audio.hpp>
-
 #else
-
 #include <QMediaPlayer>
-
 #endif
 
 #define dout qDebug()
@@ -44,10 +40,6 @@ public:
     QTime getNextPrayer();
     QString getNextPrayerLabel();
     QString getCurrPrayerLabel();
-    void initHadithList();
-    QString getRandomHadith();
-    QString getNextHadith();
-    QString getPrevHadith();
     bool isAthanPlaying();
 
     Settings * settings;
@@ -62,9 +54,6 @@ public:
 private:
 
     QTimer * timer;
-    QStringList * hadithList;
-    int currentHadithIndex;
-    int hadithCount;
     QString nextPrayerLabel;
     QString currentPrayerLabel;
 
@@ -73,6 +62,7 @@ public slots:
     void stopAthan();
     void checkAthan();
     void calculatePrayer();
+    void calculateAngle();
 
 signals:
     void athanTriggered();
